@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 ###
-### $Release: 4.0.0 $
+### $Release: 4.0.1 $
 ### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
 ### $License: Public Domain $
 ###
@@ -39,14 +39,14 @@ ex:
         @bench("format()")
         def _(bm):
             for _ in bm:
-                s = "{}{}{}{}{}".format(s1, s2, s3, s4, s5)
+                s = "{0}{1}{2}{3}{4}".format(s1, s2, s3, s4, s5)
 """
 
 from __future__ import with_statement
 
 
 __all__ = ('Benchmarker', 'Skip',)
-__version__ = '$Release: 4.0.0 $'.split()[1]
+__version__ = '$Release: 4.0.1 $'.split()[1]
 
 import sys, os, re
 from os import times as _os_times
@@ -680,7 +680,7 @@ def _parse_cmdopts(argv=None):
         if arg == "--":
             break
         if arg.startswith("--"):
-            m = re.match(r'^([-\w]+)(?:=(.*))?', arg)
+            m = re.match(r'^(\w[-\w]*)(?:=(.*))?', arg[2:])
             if not m:
                 raise CommandOptionError("%s: invalid option." % arg)
             key, val = m.groups()
