@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 
 import sys, os, re
+python2 = sys.version_info[0] == 2
+python3 = sys.version_info[0] == 3
 import unittest
 try:
     import json
 except LoadError:
     json = None
 
-from oktest import ok, test, subject, situation, skip
+from oktest import ok, test, subject, situation, skip, at_end
 from oktest.dummy import dummy_file, dummy_io
 
 from benchmarker import Benchmarker, Benchmark
@@ -34,7 +36,17 @@ def run_command(command, input=None):
         if input:
             stdin.write(input)
         stdin.close()
-        return stdout.read(), stderr.read()
+        sout = stdout.read()
+        serr = stderr.read()
+        if python2:
+            assert isinstance(sout, str)
+            assert isinstance(serr, str)
+        if python3:
+            assert isinstance(sout, bytes)
+            assert isinstance(serr, bytes)
+            sout = sout.decode('utf-8')
+            serr = serr.decode('utf-8')
+        return sout, serr
     finally:
         stdout.close()
         stderr.close()
@@ -252,9 +264,11 @@ class Benchmarker_TC(unittest.TestCase):
     @test("'-o' outputs JSON string")
     @skip.when(json is None, "failed to import json module")
     def _(self, sample_file):
+        jsonfile = "_result.json"
+        @at_end
+        def _(): os.path.exists(jsonfile) and os.unlink(jsonfile)
         s = EXPECTED_OUTPUT
         expected_pattern = output2pattern(s)
-        jsonfile = "_result.json"
         if os.path.exists(jsonfile): os.unlink(jsonfile)
         ok (jsonfile).not_exist()
         sout, serr = run_command("%s %s -o _result.json" % (sys.executable, sample_file))
@@ -521,6 +535,20 @@ DESCRIPT                D.DDDD  ( DD.D) BAR
         ok (sout).matches(expected_pattern)
         ok (serr) == ""
 
+    @test("'--name=value' sets benchmarker property.")
+    def _(self, sample_file):
+        content = r"""
+from benchmarker import Benchmarker
+from pprint import pprint
+with Benchmarker() as bench:
+    pprint(bench.properties)
+"""[1:]
+        with open(sample_file, 'w') as f:
+            f.write(content)
+        sout, serr = run_command("%s %s --str=foo --flag --num=123" % (sys.executable, sample_file))
+        ok (sout).should.startswith("{'flag': True, 'num': '123', 'str': 'foo'}\n")
+        ok (serr) == ""
+
 
 
 if __name__ == '__main__':
